nidaba package
==============

Subpackages
-----------

.. toctree::

    nidaba.algorithms
    nidaba.tasks

Submodules
----------

nidaba.celery module
--------------------

.. automodule:: nidaba.celery
    :members:
    :undoc-members:
    :show-inheritance:

nidaba.cli module
-----------------

.. automodule:: nidaba.cli
    :members:
    :undoc-members:
    :show-inheritance:

nidaba.config module
--------------------

.. automodule:: nidaba.config
    :members:
    :undoc-members:
    :show-inheritance:

nidaba.image module
-------------------

.. automodule:: nidaba.image
    :members:
    :undoc-members:
    :show-inheritance:

nidaba.lex module
-----------------

.. automodule:: nidaba.lex
    :members:
    :undoc-members:
    :show-inheritance:

nidaba.lock module
------------------

.. automodule:: nidaba.lock
    :members:
    :undoc-members:
    :show-inheritance:

nidaba.merge_hocr module
------------------------

.. automodule:: nidaba.merge_hocr
    :members:
    :undoc-members:
    :show-inheritance:

nidaba.nidaba module
--------------------

.. automodule:: nidaba.nidaba
    :members:
    :undoc-members:
    :show-inheritance:

nidaba.nidabaexceptions module
------------------------------

.. automodule:: nidaba.nidabaexceptions
    :members:
    :undoc-members:
    :show-inheritance:

nidaba.storage module
---------------------

.. automodule:: nidaba.storage
    :members:
    :undoc-members:
    :show-inheritance:

nidaba.tei module
-----------------

.. automodule:: nidaba.tei
    :members:
    :undoc-members:
    :show-inheritance:

nidaba.uzn module
-----------------

.. automodule:: nidaba.uzn
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: nidaba
    :members:
    :undoc-members:
    :show-inheritance:
